@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11228 2018-09-18 13:29:34Z Lavender $
+# $Id: __init__.py 11248 2018-10-18 08:40:13Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-09-18 22:29:34 +0900 (週二, 18 九月 2018) $
-# $Revision: 11228 $
+# $Date: 2018-10-18 17:40:13 +0900 (週四, 18 十月 2018) $
+# $Revision: 11248 $
 
 import os
 import sys
@@ -195,7 +195,7 @@ def attachSettings(settingsDict, enablePaypal=False):
     # Django haystack connections.
     BASE_DIR = settingsDict['BASE_DIR']
     if settingsDict['DEBUG'] or sys.platform.startswith("win32"):
-        HAYSTACK_SETTINGS = {
+        ADDING_HAYSTACK_CONNECTIONS = {
             'HAYSTACK_CONNECTIONS': {
                 'default': {
                     'ENGINE': (
@@ -205,7 +205,7 @@ def attachSettings(settingsDict, enablePaypal=False):
             },
         }
     else:
-        HAYSTACK_SETTINGS = {
+        ADDING_HAYSTACK_CONNECTIONS = {
             'HAYSTACK_CONNECTIONS': {
                 'default': {
                     'ENGINE': 'xapian_backend.XapianEngine',
