@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11208 2018-08-25 14:31:26Z Lavender $
+# $Id: views.py 11223 2018-09-09 07:48:50Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-08-25 23:31:26 +0900 (週六, 25 八月 2018) $
-# $Revision: 11208 $ 
+# $Date: 2018-09-09 16:48:50 +0900 (週日, 09 九月 2018) $
+# $Revision: 11223 $ 
 
 import json
 import logging
@@ -573,6 +573,36 @@ class CathaybkCreditTransactionListView(generic.ListView):
     model = CathaybkCreditTrade
     template_name = 'shop/payment/dashboard/CathayCredit.html'
     context_object_name = 'transactions'
+    
+# https://code.nuwainfo.com/trac/phantasos/ticket/589#ticket
+from oscar.apps.dashboard.catalogue import tables
+from oscar.apps.dashboard.catalogue import views as catalogueViews
+from oscar.core.loading import get_model
+from django_tables2 import A, TemplateColumn
+from django.utils.translation import ugettext_lazy as _
+
+Product = get_model('catalogue', 'Product')
+
+class ProductTable(tables.ProductTable):
+    categories = TemplateColumn(
+        verbose_name=_('Categories'),
+        accessor=A('categories'),
+        template_name='shop/dashboard/catalogue/ProductRowCategory.html',
+        orderable=False,
+    )
+
+    class Meta(tables.ProductTable.Meta):
+        model = Product
+        fields = ('upc', 'date_updated')
+        sequence = ('title', 'upc', 'image', 'product_class', 
+                    'categories', 'variants',
+                    'stock_records', '...', 'date_updated', 'actions')
+        order_by = '-date_updated'
+        
+catalogueViews.ProductListView.table_class = ProductTable
+
+    
+
         
     
 
